<?php
/**
 * Plugin Name: Fliz Video Generator
 * Plugin URI: https://fliz.ai
 * Description: Create videos in 1 click using Fliz AI and insert them directly into your WordPress posts
 * Version: 1.1.0
 * Requires at least: 5.0
 * Requires PHP: 7.4
 * Author: Fliz.ai
 * License: GPL v2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: fliz-video-generator
 * Domain Path: /languages
 *
 * @package FlizVideoGenerator
 */

if (!defined('ABSPATH')) {
    exit;
}

// Définition des constantes
define('FLIZ_VIDEO_GENERATOR_VERSION', '1.1.0');
define('FLIZ_VIDEO_GENERATOR_PATH', plugin_dir_path(__FILE__));
define('FLIZ_VIDEO_GENERATOR_URL', plugin_dir_url(__FILE__));

// Chargement automatique des classes
spl_autoload_register(function ($class) {
    $prefix = 'FlizVideoGenerator\\';
    $base_dir = FLIZ_VIDEO_GENERATOR_PATH . 'includes/';

    if (strncmp($prefix, $class, strlen($prefix)) !== 0) {
        return;
    }

    $relative_class = substr($class, strlen($prefix));
    $file = $base_dir . str_replace('\\', '/', $relative_class) . '.php';

    if (file_exists($file)) {
        require $file;
    }
});

// Initialisation du plugin
function fliz_video_generator_init() {
    // Chargement des classes principales
    $settings = new \FlizVideoGenerator\Admin\Settings();
    new \FlizVideoGenerator\Admin\Menu();
    new \FlizVideoGenerator\Admin\MetaBox();
    new \FlizVideoGenerator\Admin\LogViewer();
    new \FlizVideoGenerator\Shortcode\VideoShortcode();
    new \FlizVideoGenerator\AutoGenerator\VideoGenerator();
    new \FlizVideoGenerator\Admin\BulkGenerator();
    
    $api = new \FlizVideoGenerator\Api\FlizApi();
    add_action('wp_ajax_fliz_check_video', [$api, 'ajax_check_video_status']);
    add_action('wp_ajax_nopriv_fliz_check_video', [$api, 'ajax_check_video_status']);
}
add_action('plugins_loaded', 'fliz_video_generator_init');

// Activation du plugin
register_activation_hook(__FILE__, function() {
    // Création de la table de logs
    \FlizVideoGenerator\Logger\VideoLogger::create_table();
});

// Désactivation du plugin
register_deactivation_hook(__FILE__, function() {
    delete_option('fliz_api_key');
}); 