<?php
namespace FlizVideoGenerator\Admin;

class LogViewer {
    public function __construct() {
        add_action('admin_menu', [$this, 'add_menu_page']);
        add_action('admin_enqueue_scripts', [$this, 'enqueue_scripts']);
    }

    public function add_menu_page() {
        add_submenu_page(
            'edit.php',
            __('Logs Fliz Video', 'fliz-video-generator'),
            __('Logs Vidéo', 'fliz-video-generator'),
            'manage_options',
            'fliz-video-logs',
            [$this, 'render_page']
        );
    }

    public function render_page() {
        $logs = \FlizVideoGenerator\Logger\VideoLogger::get_logs();
        ?>
        <div class="wrap">
            <h1><?php echo esc_html__('Logs de Génération Vidéo', 'fliz-video-generator'); ?></h1>
            
            <div class="tablenav top">
                <div class="alignleft actions">
                    <select id="fliz-log-filter">
                        <option value=""><?php esc_html_e('Tous les statuts', 'fliz-video-generator'); ?></option>
                        <option value="pending"><?php esc_html_e('En attente', 'fliz-video-generator'); ?></option>
                        <option value="completed"><?php esc_html_e('Terminé', 'fliz-video-generator'); ?></option>
                        <option value="error"><?php esc_html_e('Erreur', 'fliz-video-generator'); ?></option>
                    </select>
                    <button class="button" id="fliz-refresh-logs">
                        <?php esc_html_e('Rafraîchir', 'fliz-video-generator'); ?>
                    </button>
                </div>
            </div>

            <table class="wp-list-table widefat fixed striped">
                <thead>
                    <tr>
                        <th><?php esc_html_e('Date', 'fliz-video-generator'); ?></th>
                        <th><?php esc_html_e('Article', 'fliz-video-generator'); ?></th>
                        <th><?php esc_html_e('ID Vidéo', 'fliz-video-generator'); ?></th>
                        <th><?php esc_html_e('Statut', 'fliz-video-generator'); ?></th>
                        <th><?php esc_html_e('Message', 'fliz-video-generator'); ?></th>
                        <th><?php esc_html_e('Actions', 'fliz-video-generator'); ?></th>
                    </tr>
                </thead>
                <tbody id="fliz-logs-table">
                    <?php $this->render_logs_rows($logs); ?>
                </tbody>
            </table>
        </div>
        <?php
    }

    private function render_logs_rows($logs) {
        foreach ($logs as $log) {
            $post = get_post($log->post_id);
            $status_class = $this->get_status_class($log->status);
            ?>
            <tr data-status="<?php echo esc_attr($log->status); ?>">
                <td>
                    <?php echo esc_html(
                        wp_date(
                            get_option('date_format') . ' ' . get_option('time_format'),
                            strtotime($log->created_at)
                        )
                    ); ?>
                </td>
                <td>
                    <?php if ($post): ?>
                        <a href="<?php echo esc_url(get_edit_post_link($post->ID)); ?>">
                            <?php echo esc_html($post->post_title); ?>
                        </a>
                    <?php else: ?>
                        <?php esc_html_e('Article supprimé', 'fliz-video-generator'); ?>
                    <?php endif; ?>
                </td>
                <td><?php echo esc_html($log->video_id); ?></td>
                <td>
                    <span class="fliz-status <?php echo esc_attr($status_class); ?>">
                        <?php echo esc_html($this->get_status_label($log->status)); ?>
                    </span>
                </td>
                <td><?php echo esc_html($log->message); ?></td>
                <td>
                    <?php if ($log->status === 'pending'): ?>
                        <button class="button fliz-check-status" 
                                data-video-id="<?php echo esc_attr($log->video_id); ?>">
                            <?php esc_html_e('Vérifier', 'fliz-video-generator'); ?>
                        </button>
                    <?php endif; ?>
                </td>
            </tr>
            <?php
        }
    }

    private function get_status_class($status) {
        switch ($status) {
            case 'pending':
                return 'status-pending';
            case 'completed':
                return 'status-completed';
            case 'error':
                return 'status-error';
            default:
                return '';
        }
    }

    private function get_status_label($status) {
        switch ($status) {
            case 'pending':
                return __('En attente', 'fliz-video-generator');
            case 'completed':
                return __('Terminé', 'fliz-video-generator');
            case 'error':
                return __('Erreur', 'fliz-video-generator');
            default:
                return $status;
        }
    }

    public function enqueue_scripts($hook) {
        if ($hook !== 'posts_page_fliz-video-logs') {
            return;
        }

        wp_enqueue_style(
            'fliz-admin-logs',
            FLIZ_VIDEO_GENERATOR_URL . 'assets/css/admin-logs.css',
            [],
            FLIZ_VIDEO_GENERATOR_VERSION
        );

        wp_enqueue_script(
            'fliz-admin-logs',
            FLIZ_VIDEO_GENERATOR_URL . 'assets/js/admin-logs.js',
            ['jquery'],
            FLIZ_VIDEO_GENERATOR_VERSION,
            true
        );

        wp_localize_script('fliz-admin-logs', 'flizLogs', [
            'ajaxurl' => admin_url('admin-ajax.php'),
            'nonce' => wp_create_nonce('fliz_logs_nonce'),
            'checking' => __('Vérification...', 'fliz-video-generator'),
            'error' => __('Erreur lors de la vérification', 'fliz-video-generator')
        ]);
    }
} 