<?php
namespace FlizVideoGenerator\Admin;

class MetaBox {
    public function __construct() {
        add_action('add_meta_boxes', [$this, 'add_meta_box']);
        add_action('admin_enqueue_scripts', [$this, 'enqueue_scripts']);
        add_action('wp_ajax_fliz_generate_video', [$this, 'handle_video_generation']);
    }

    public function add_meta_box() {
        add_meta_box(
            'fliz_video_generator',
            $this->get_translated_text('title'),
            [$this, 'render_meta_box'],
            'post',
            'side',
            'high'
        );
    }

    private function get_translated_text($key) {
        $locale = get_locale();
        $translations = [
            'title' => [
                'fr_FR' => 'Fliz Video Generator',
                'es_ES' => 'Fliz Video Generator',
                'it_IT' => 'Fliz Video Generator',
                'de_DE' => 'Fliz Video Generator',
                'pt_PT' => 'Fliz Video Generator',
                'default' => 'Fliz Video Generator'
            ],
            'video_type' => [
                'fr_FR' => 'Type de vidéo :',
                'es_ES' => 'Tipo de video:',
                'it_IT' => 'Tipo di video:',
                'de_DE' => 'Videotyp:',
                'pt_PT' => 'Tipo de vídeo:',
                'default' => 'Video type:'
            ],
            'format' => [
                'fr_FR' => 'Format :',
                'es_ES' => 'Formato:',
                'it_IT' => 'Formato:',
                'de_DE' => 'Format:',
                'pt_PT' => 'Formato:',
                'default' => 'Format:'
            ],
            'article' => [
                'fr_FR' => 'Article',
                'es_ES' => 'Artículo',
                'it_IT' => 'Articolo',
                'de_DE' => 'Artikel',
                'pt_PT' => 'Artigo',
                'default' => 'Article'
            ],
            'ad' => [
                'fr_FR' => 'Publicité',
                'es_ES' => 'Publicidad',
                'it_IT' => 'Pubblicità',
                'de_DE' => 'Werbung',
                'pt_PT' => 'Publicidade',
                'default' => 'Advertisement'
            ],
            'product' => [
                'fr_FR' => 'Produit',
                'es_ES' => 'Producto',
                'it_IT' => 'Prodotto',
                'de_DE' => 'Produkt',
                'pt_PT' => 'Produto',
                'default' => 'Product'
            ],
            'square' => [
                'fr_FR' => 'Carré',
                'es_ES' => 'Cuadrado',
                'it_IT' => 'Quadrato',
                'de_DE' => 'Quadratisch',
                'pt_PT' => 'Quadrado',
                'default' => 'Square'
            ],
            'shortcode' => [
                'fr_FR' => 'Shortcode :',
                'es_ES' => 'Shortcode:',
                'it_IT' => 'Shortcode:',
                'de_DE' => 'Shortcode:',
                'pt_PT' => 'Shortcode:',
                'default' => 'Shortcode:'
            ],
            'generate_button' => [
                'fr_FR' => 'Générer une vidéo',
                'es_ES' => 'Generar video',
                'it_IT' => 'Genera video',
                'de_DE' => 'Video generieren',
                'pt_PT' => 'Gerar vídeo',
                'default' => 'Generate video'
            ]
        ];

        return $translations[$key][$locale] ?? $translations[$key]['default'];
    }

    public function render_meta_box($post) {
        $video_id = get_post_meta($post->ID, '_fliz_video_id', true);
        ?>
        <div>
            <p>
                <label for="fliz_video_type"><?php echo esc_html($this->get_translated_text('video_type')); ?></label><br>
                <select name="fliz_video_type" id="fliz_video_type">
                    <option value="article"><?php echo esc_html($this->get_translated_text('article')); ?></option>
                    <option value="ad"><?php echo esc_html($this->get_translated_text('ad')); ?></option>
                    <option value="product"><?php echo esc_html($this->get_translated_text('product')); ?></option>
                </select>
            </p>

            <p>
                <label for="fliz_video_format"><?php echo esc_html($this->get_translated_text('format')); ?></label><br>
                <select name="fliz_video_format" id="fliz_video_format">
                    <option value="size_16_9">16:9</option>
                    <option value="size_9_16">9:16</option>
                    <option value="square"><?php echo esc_html($this->get_translated_text('square')); ?></option>
                </select>
            </p>

            <?php if ($video_id): ?>
            <p>
                <label><?php echo esc_html($this->get_translated_text('shortcode')); ?></label><br>
                <code>[fliz_video id="<?php echo esc_attr($video_id); ?>"]</code>
            </p>
            <?php endif; ?>

            <p>
                <button type="button" class="button button-primary" id="generate-video">
                    <?php echo esc_html($this->get_translated_text('generate_button')); ?>
                </button>
            </p>
        </div>
        <?php
    }

    public function enqueue_scripts($hook) {
        if ($hook !== 'post.php' && $hook !== 'post-new.php') {
            return;
        }

        wp_enqueue_script(
            'fliz-admin',
            FLIZ_VIDEO_GENERATOR_URL . 'assets/js/admin.js',
            ['jquery'],
            FLIZ_VIDEO_GENERATOR_VERSION,
            true
        );

        // Ajout des données nécessaires pour le JavaScript
        wp_localize_script('fliz-admin', 'flizAdmin', [
            'ajaxurl' => admin_url('admin-ajax.php'),
            'nonce' => wp_create_nonce('fliz_generate_video_nonce'),
            'generating' => __('Génération en cours...', 'fliz-video-generator'),
            'generateText' => __('Générer une vidéo', 'fliz-video-generator')
        ]);
    }

    public function handle_video_generation() {
        check_ajax_referer('fliz_generate_video_nonce', 'nonce');

        if (!current_user_can('edit_posts')) {
            wp_send_json_error(__('Permission refusée', 'fliz-video-generator'));
        }

        $post_id = intval($_POST['post_id']);
        $video_type = sanitize_text_field($_POST['video_type']);
        $video_format = sanitize_text_field($_POST['video_format']);

        $post = get_post($post_id);
        if (!$post) {
            wp_send_json_error(__('Article introuvable', 'fliz-video-generator'));
        }

        $api = new \FlizVideoGenerator\Api\FlizApi();
        
        // Vérification des crédits
        $credits = $api->get_credits();
        if (is_wp_error($credits)) {
            wp_send_json_error($credits->get_error_message());
        }
        if ($credits <= 0) {
            wp_send_json_error(__('Vous n\'avez plus de crédits disponibles', 'fliz-video-generator'));
        }

        $input = [
            'post_id' => $post_id,
            'name' => $post->post_title,
            'description' => wp_strip_all_tags($post->post_content),
            'site_url' => get_permalink($post_id),
            'site_name' => get_bloginfo('name'),
            'lang' => substr(get_locale(), 0, 2),
            'format' => $video_format,
            'category' => $video_type
        ];

        $result = $api->create_video($input);

        if (is_wp_error($result)) {
            wp_send_json_error($result->get_error_message());
        }

        if (!isset($result['fliz_video_create']['video_id'])) {
            wp_send_json_error(__('ID de vidéo manquant dans la réponse', 'fliz-video-generator'));
        }

        $video_id = $result['fliz_video_create']['video_id'];
        update_post_meta($post_id, '_fliz_video_id', $video_id);

        // Ajouter le shortcode à la fin de l'article
        $content = $post->post_content;
        if (substr($content, -1) !== "\n") {
            $content .= "\n";
        }
        $content .= "\n[fliz_video id=\"" . $video_id . "\"]";

        wp_update_post([
            'ID' => $post_id,
            'post_content' => $content
        ]);

        // Logger la génération
        \FlizVideoGenerator\Logger\VideoLogger::log(
            $post_id,
            $video_id,
            'pending',
            __('Génération de vidéo initiée', 'fliz-video-generator')
        );

        wp_send_json_success();
    }
} 