<?php
namespace FlizVideoGenerator\Admin;

class PostList extends \WP_List_Table {
    private function get_translated_text($key) {
        $locale = get_locale();
        $translations = [
            'title' => [
                'fr_FR' => 'Titre',
                'es_ES' => 'Título',
                'it_IT' => 'Titolo',
                'de_DE' => 'Titel',
                'pt_PT' => 'Título',
                'default' => 'Title'
            ],
            'author' => [
                'fr_FR' => 'Auteur',
                'es_ES' => 'Autor',
                'it_IT' => 'Autore',
                'de_DE' => 'Autor',
                'pt_PT' => 'Autor',
                'default' => 'Author'
            ],
            'categories' => [
                'fr_FR' => 'Catégories',
                'es_ES' => 'Categorías',
                'it_IT' => 'Categorie',
                'de_DE' => 'Kategorien',
                'pt_PT' => 'Categorias',
                'default' => 'Categories'
            ],
            'video_fliz' => [
                'fr_FR' => 'Vidéo Fliz',
                'es_ES' => 'Video Fliz',
                'it_IT' => 'Video Fliz',
                'de_DE' => 'Fliz Video',
                'pt_PT' => 'Vídeo Fliz',
                'default' => 'Fliz Video'
            ],
            'date' => [
                'fr_FR' => 'Date',
                'es_ES' => 'Fecha',
                'it_IT' => 'Data',
                'de_DE' => 'Datum',
                'pt_PT' => 'Data',
                'default' => 'Date'
            ],
            'all_categories' => [
                'fr_FR' => 'Toutes les catégories',
                'es_ES' => 'Todas las categorías',
                'it_IT' => 'Tutte le categorie',
                'de_DE' => 'Alle Kategorien',
                'pt_PT' => 'Todas as categorias',
                'default' => 'All categories'
            ],
            'all_authors' => [
                'fr_FR' => 'Tous les auteurs',
                'es_ES' => 'Todos los autores',
                'it_IT' => 'Tutti gli autori',
                'de_DE' => 'Alle Autoren',
                'pt_PT' => 'Todos os autores',
                'default' => 'All authors'
            ],
            'all_dates' => [
                'fr_FR' => 'Toutes les dates',
                'es_ES' => 'Todas las fechas',
                'it_IT' => 'Tutte le date',
                'de_DE' => 'Alle Daten',
                'pt_PT' => 'Todas as datas',
                'default' => 'All dates'
            ],
            'filter' => [
                'fr_FR' => 'Filtrer',
                'es_ES' => 'Filtrar',
                'it_IT' => 'Filtra',
                'de_DE' => 'Filtern',
                'pt_PT' => 'Filtrar',
                'default' => 'Filter'
            ],
            'generate_videos' => [
                'fr_FR' => 'Générer des vidéos',
                'es_ES' => 'Generar videos',
                'it_IT' => 'Genera video',
                'de_DE' => 'Videos generieren',
                'pt_PT' => 'Gerar vídeos',
                'default' => 'Generate videos'
            ]
        ];

        return $translations[$key][$locale] ?? $translations[$key]['default'];
    }

    public function __construct() {
        parent::__construct([
            'singular' => 'post',
            'plural'   => 'posts',
            'ajax'     => false
        ]);
    }

    public function get_columns() {
        return [
            'cb' => '<input type="checkbox" />',
            'title' => $this->get_translated_text('title'),
            'author' => $this->get_translated_text('author'),
            'categories' => $this->get_translated_text('categories'),
            'has_video' => $this->get_translated_text('video_fliz'),
            'date' => $this->get_translated_text('date')
        ];
    }

    public function prepare_items() {
        $columns = $this->get_columns();
        $hidden = array();
        $sortable = $this->get_sortable_columns();
        $this->_column_headers = array($columns, $hidden, $sortable);

        $per_page = 20;
        $current_page = $this->get_pagenum();

        // Paramètres de requête
        $args = [
            'post_type' => 'post',
            'posts_per_page' => $per_page,
            'paged' => $current_page,
            'orderby' => isset($_REQUEST['orderby']) ? $_REQUEST['orderby'] : 'date',
            'order' => isset($_REQUEST['order']) ? $_REQUEST['order'] : 'DESC',
        ];

        // Filtre par statut
        if (isset($_REQUEST['post_status']) && $_REQUEST['post_status'] !== 'all') {
            $args['post_status'] = $_REQUEST['post_status'];
        } else {
            $args['post_status'] = ['publish', 'draft', 'pending'];
        }

        // Filtre par catégorie
        if (!empty($_REQUEST['cat'])) {
            $args['cat'] = intval($_REQUEST['cat']);
        }

        // Filtre par auteur
        if (!empty($_REQUEST['author'])) {
            $args['author'] = intval($_REQUEST['author']);
        }

        // Filtre par date
        if (!empty($_REQUEST['m'])) {
            $args['m'] = $_REQUEST['m'];
        }

        // Filtre vidéo Fliz
        if (isset($_REQUEST['has_fliz_video'])) {
            $args['meta_query'] = [
                [
                    'key' => '_fliz_video_id',
                    'compare' => $_REQUEST['has_fliz_video'] === 'yes' ? 'EXISTS' : 'NOT EXISTS'
                ]
            ];
        }

        // Recherche
        if (!empty($_REQUEST['s'])) {
            $args['s'] = $_REQUEST['s'];
        }

        $query = new \WP_Query($args);
        $this->items = $query->posts;
        $total_items = $query->found_posts;

        $this->set_pagination_args([
            'total_items' => $total_items,
            'per_page'    => $per_page,
            'total_pages' => ceil($total_items / $per_page)
        ]);
    }

    protected function get_views() {
        global $wpdb;
        $views = [];
        $current = isset($_GET['has_fliz_video']) ? $_GET['has_fliz_video'] : '';

        $all_text = [
            'fr_FR' => 'Tous',
            'es_ES' => 'Todos',
            'it_IT' => 'Tutti',
            'de_DE' => 'Alle',
            'pt_PT' => 'Todos',
            'default' => 'All'
        ];

        $without_video_text = [
            'fr_FR' => 'Sans vidéo',
            'es_ES' => 'Sin video',
            'it_IT' => 'Senza video',
            'de_DE' => 'Ohne Video',
            'pt_PT' => 'Sem vídeo',
            'default' => 'Without video'
        ];

        $with_video_text = [
            'fr_FR' => 'Avec vidéo',
            'es_ES' => 'Con video',
            'it_IT' => 'Con video',
            'de_DE' => 'Mit Video',
            'pt_PT' => 'Com vídeo',
            'default' => 'With video'
        ];

        $locale = get_locale();

        // Tous les articles
        $class = empty($current) ? ' class="current"' : '';
        $views['all'] = sprintf(
            '<a href="%s"%s>%s</a>',
            remove_query_arg('has_fliz_video'),
            $class,
            $all_text[$locale] ?? $all_text['default']
        );

        // Articles sans vidéo
        $class = $current === 'no' ? ' class="current"' : '';
        $views['no_video'] = sprintf(
            '<a href="%s"%s>%s</a>',
            add_query_arg('has_fliz_video', 'no'),
            $class,
            $without_video_text[$locale] ?? $without_video_text['default']
        );

        // Articles avec vidéo
        $class = $current === 'yes' ? ' class="current"' : '';
        $views['has_video'] = sprintf(
            '<a href="%s"%s>%s</a>',
            add_query_arg('has_fliz_video', 'yes'),
            $class,
            $with_video_text[$locale] ?? $with_video_text['default']
        );

        return $views;
    }

    protected function extra_tablenav($which) {
        if ($which !== 'top') return;
        ?>
        <div class="alignleft actions">
            <?php
            // Filtre par catégorie
            wp_dropdown_categories([
                'show_option_all' => $this->get_translated_text('all_categories'),
                'orderby' => 'name',
                'selected' => isset($_REQUEST['cat']) ? $_REQUEST['cat'] : '',
                'name' => 'cat',
                'hide_empty' => false
            ]);

            // Filtre par auteur
            wp_dropdown_users([
                'show_option_all' => $this->get_translated_text('all_authors'),
                'name' => 'author',
                'selected' => isset($_REQUEST['author']) ? $_REQUEST['author'] : ''
            ]);

            // Filtre par date
            global $wp_locale;
            $months = $this->get_months_dropdown();
            if ($months) {
                $selected = isset($_REQUEST['m']) ? $_REQUEST['m'] : 0;
                echo '<select name="m">';
                echo '<option value="0"' . selected($selected, 0, false) . '>' . $this->get_translated_text('all_dates') . '</option>';
                foreach ($months as $arc_row) {
                    $month = zeroise($arc_row->month, 2);
                    $year = $arc_row->year;
                    printf(
                        "<option value='%s'%s>%s</option>\n",
                        esc_attr($arc_row->year . $month),
                        selected($selected, $year . $month, false),
                        sprintf(__('%1$s %2$d'), $wp_locale->get_month($month), $year)
                    );
                }
                echo '</select>';
            }

            submit_button($this->get_translated_text('filter'), '', 'filter_action', false);
            ?>
        </div>
        <?php
    }

    // Ajout de la fonction pour récupérer les mois
    private function get_months_dropdown() {
        global $wpdb;
        
        $months = $wpdb->get_results("
            SELECT DISTINCT YEAR(post_date) AS year, MONTH(post_date) AS month
            FROM $wpdb->posts
            WHERE post_type = 'post' AND post_status IN ('publish', 'draft', 'pending')
            ORDER BY post_date DESC
        ");

        return $months;
    }

    protected function column_default($item, $column_name) {
        switch ($column_name) {
            case 'title':
                return $this->column_title($item);
            case 'author':
                return $this->column_author($item);
            case 'categories':
                return $this->column_categories($item);
            case 'has_video':
                return $this->column_has_video($item);
            case 'date':
                return $this->column_date($item);
            default:
                return print_r($item, true);
        }
    }

    protected function column_cb($item) {
        return sprintf(
            '<input type="checkbox" name="posts[]" value="%s" />',
            $item->ID
        );
    }

    protected function column_title($item) {
        $title = empty($item->post_title) ? __('(sans titre)') : $item->post_title;
        
        return sprintf(
            '<a href="%s"><strong>%s</strong></a>',
            get_edit_post_link($item->ID),
            esc_html($title)
        );
    }

    protected function column_author($item) {
        $author = get_user_by('id', $item->post_author);
        return $author ? esc_html($author->display_name) : '';
    }

    protected function column_categories($item) {
        $categories = get_the_category($item->ID);
        $cat_links = [];
        foreach ($categories as $cat) {
            $cat_links[] = sprintf(
                '<a href="%s">%s</a>',
                esc_url(add_query_arg(['cat' => $cat->term_id])),
                esc_html($cat->name)
            );
        }
        return implode(', ', $cat_links);
    }

    protected function column_has_video($item) {
        $video_id = get_post_meta($item->ID, '_fliz_video_id', true);
        if ($video_id) {
            return sprintf(
                '<span class="dashicons dashicons-yes" style="color: #46b450;" title="%s"></span>',
                esc_attr__('Vidéo générée', 'fliz-video-generator')
            );
        }
        return sprintf(
            '<span class="dashicons dashicons-no" style="color: #dc3232;" title="%s"></span>',
            esc_attr__('Pas de vidéo', 'fliz-video-generator')
        );
    }

    protected function column_date($item) {
        return get_the_date('', $item);
    }

    protected function get_sortable_columns() {
        return [
            'title' => ['title', true],
            'author' => ['author', false],
            'date' => ['date', true]
        ];
    }

    protected function get_bulk_actions() {
        return []; // On retire le menu déroulant
    }

    public function display() {
        // Ajout du bouton "Générer des vidéos" avant l'affichage de la table
        echo '<div class="tablenav top">';
        echo '<div class="alignleft actions bulkactions">';
        echo '<button type="button" class="button button-primary" id="generate-video-button">' . 
             esc_html($this->get_translated_text('generate_videos')) . 
             '</button>';
        echo '</div>';
        echo '</div>';

        parent::display();
    }
} 