<?php
namespace FlizVideoGenerator\AutoGenerator;

class VideoGenerator {
    private $api;

    public function __construct() {
        $this->api = new \FlizVideoGenerator\Api\FlizApi();
        add_action('transition_post_status', [$this, 'handle_post_status_transition'], 10, 3);
        add_action('fliz_check_pending_videos', [$this, 'check_pending_videos']);
    }

    public function handle_post_status_transition($new_status, $old_status, $post) {
        // Vérifier si c'est une publication d'article
        if ($new_status === 'publish' && $old_status !== 'publish' && $post->post_type === 'post') {
            // Vérifier si la génération automatique est activée pour cet article
            if (get_post_meta($post->ID, '_fliz_generate_video', true)) {
                $this->generate_video_for_post($post);
            }
        }
    }

    public function generate_video_for_post($post) {
        $input = [
            'name' => $post->post_title,
            'description' => wp_strip_all_tags($post->post_content),
            'site_url' => get_permalink($post->ID),
            'site_name' => get_bloginfo('name'),
            'lang' => substr(get_locale(), 0, 2),
            'format' => get_post_meta($post->ID, '_fliz_video_format', true) ?: 'size_16_9',
            'category' => get_post_meta($post->ID, '_fliz_video_type', true) ?: 'article'
        ];

        $result = $this->api->create_video($input);

        if (is_wp_error($result)) {
            \FlizVideoGenerator\Logger\VideoLogger::log(
                $post->ID,
                '',
                'error',
                $result->get_error_message()
            );
            return false;
        }

        $video_id = $result['fliz_video_create']['video_id'];
        update_post_meta($post->ID, '_fliz_video_id', $video_id);
        
        \FlizVideoGenerator\Logger\VideoLogger::log(
            $post->ID,
            $video_id,
            'pending',
            'Génération de vidéo initiée'
        );

        // Planifier une vérification du statut
        wp_schedule_single_event(time() + 300, 'fliz_check_pending_videos');

        return true;
    }

    public function check_pending_videos() {
        global $wpdb;
        
        $logs = $wpdb->get_results(
            "SELECT * FROM {$wpdb->prefix}fliz_video_logs 
            WHERE status = 'pending' 
            ORDER BY created_at DESC"
        );

        foreach ($logs as $log) {
            $result = $this->api->get_video_status($log->video_id);
            
            if (is_wp_error($result)) {
                \FlizVideoGenerator\Logger\VideoLogger::update_status(
                    $log->video_id,
                    'error',
                    $result->get_error_message()
                );
                continue;
            }

            if (isset($result['fliz_video_by_pk']['url'])) {
                \FlizVideoGenerator\Logger\VideoLogger::update_status(
                    $log->video_id,
                    'completed',
                    'Vidéo générée avec succès'
                );
            } else {
                // Replanifier une vérification dans 5 minutes
                wp_schedule_single_event(time() + 300, 'fliz_check_pending_videos');
            }
        }
    }
} 