<?php
namespace FlizVideoGenerator\Logger;

class VideoLogger {
    const LOG_TABLE = 'fliz_video_logs';

    public static function create_table() {
        global $wpdb;
        
        $table_name = $wpdb->prefix . self::LOG_TABLE;
        $charset_collate = $wpdb->get_charset_collate();

        $sql = "CREATE TABLE IF NOT EXISTS $table_name (
            id bigint(20) NOT NULL AUTO_INCREMENT,
            post_id bigint(20) NOT NULL,
            video_id varchar(36) NOT NULL,
            status varchar(50) NOT NULL,
            message text NULL,
            created_at datetime DEFAULT CURRENT_TIMESTAMP,
            updated_at datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
            PRIMARY KEY  (id),
            KEY post_id (post_id),
            KEY video_id (video_id)
        ) $charset_collate;";

        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        dbDelta($sql);
    }

    public static function log($post_id, $video_id, $status, $message = '') {
        global $wpdb;
        
        $wpdb->insert(
            $wpdb->prefix . self::LOG_TABLE,
            [
                'post_id' => $post_id,
                'video_id' => $video_id,
                'status' => $status,
                'message' => $message
            ],
            ['%d', '%s', '%s', '%s']
        );
    }

    public static function update_status($video_id, $status, $message = '') {
        global $wpdb;
        
        $wpdb->update(
            $wpdb->prefix . self::LOG_TABLE,
            [
                'status' => $status,
                'message' => $message
            ],
            ['video_id' => $video_id],
            ['%s', '%s'],
            ['%s']
        );
    }

    public static function get_logs($post_id = null) {
        global $wpdb;
        
        $table = $wpdb->prefix . self::LOG_TABLE;
        
        if ($post_id) {
            return $wpdb->get_results(
                $wpdb->prepare(
                    "SELECT * FROM $table WHERE post_id = %d ORDER BY created_at DESC",
                    $post_id
                )
            );
        }
        
        return $wpdb->get_results("SELECT * FROM $table ORDER BY created_at DESC LIMIT 100");
    }
} 