<?php
namespace FlizVideoGenerator\Shortcode;

class VideoShortcode {
    private $api;

    public function __construct() {
        $this->api = new \FlizVideoGenerator\Api\FlizApi();
        add_shortcode('fliz_video', [$this, 'render_shortcode']);
        add_action('wp_enqueue_scripts', [$this, 'enqueue_scripts']);
    }

    public function render_shortcode($atts) {
        $atts = shortcode_atts([
            'id' => '',
            'width' => '100%',
            'height' => 'auto'
        ], $atts, 'fliz_video');

        if (empty($atts['id'])) {
            return '';
        }

        // Récupération du statut de la vidéo
        $video = $this->api->get_video_status($atts['id']);
        
        if (is_wp_error($video)) {
            return '';
        }

        // Si la vidéo n'est pas encore prête
        if (!isset($video['fliz_video_by_pk']['url'])) {
            return sprintf(
                '<div class="fliz-video-pending" data-video-id="%s">%s</div>',
                esc_attr($atts['id']),
                esc_html__('Vidéo en cours de génération...', 'fliz-video-generator')
            );
        }

        $video_url = $video['fliz_video_by_pk']['url'];
        
        return sprintf(
            '<div class="fliz-video-wrapper" style="width: %1$s;">
                <video controls style="width: 100%%; height: %2$s;">
                    <source src="%3$s" type="video/mp4">
                    %4$s
                </video>
            </div>',
            esc_attr($atts['width']),
            esc_attr($atts['height']),
            esc_url($video_url),
            esc_html__('Votre navigateur ne supporte pas la lecture de vidéos.', 'fliz-video-generator')
        );
    }

    public function enqueue_scripts() {
        wp_enqueue_style(
            'fliz-video',
            FLIZ_VIDEO_GENERATOR_URL . 'assets/css/video.css',
            [],
            FLIZ_VIDEO_GENERATOR_VERSION
        );

        wp_enqueue_script(
            'fliz-video',
            FLIZ_VIDEO_GENERATOR_URL . 'assets/js/video.js',
            ['jquery'],
            FLIZ_VIDEO_GENERATOR_VERSION,
            true
        );

        wp_localize_script('fliz-video', 'flizVideo', [
            'ajaxurl' => admin_url('admin-ajax.php'),
            'nonce' => wp_create_nonce('fliz_video_nonce')
        ]);
    }
} 